@@ -2,7 +2,7 @@
 
 __author__ = """Qiusheng Wu"""
 __email__ = "giswqs@gmail.com"
-__version__ = "0.18.0"
+__version__ = "0.19.0"
 
 import os
 
@@ -25,6 +25,19 @@ def use_folium():
         return False
 
 
+def _use_eerepr(token="USE_EEREPR"):
+    """Whether to use eerepr for printing Earth Engine objects.
+
+    Returns:
+        bool: True if eerepr is used for printing Earth Engine objects.
+    """
+
+    if os.environ.get(token) is None:
+        return True
+    else:
+        return False
+
+
 if use_folium():
     from .foliumap import *
 else:
@@ -41,4 +54,7 @@ else:
             )
         raise Exception(e)
 
+if _use_eerepr():
+    import eerepr
+
 from .report import Report
