@@ -11,13 +11,7 @@ import requests
 import ipywidgets as widgets
 from box import Box
 from .basemaps import xyz_to_heremap
-from .common import (
-    ee_initialize,
-    shp_to_geojson,
-    gdf_to_geojson,
-    vector_to_geojson,
-    random_string,
-)
+from .common import *
 from . import examples
 
 try:
@@ -266,12 +260,21 @@ class Map(here_map_widget.Map):
         elif isinstance(ee_object, ee.imagecollection.ImageCollection):
             image = ee_object.mosaic()
 
-        if "palette" in vis_params and isinstance(vis_params["palette"], Box):
-            try:
-                vis_params["palette"] = vis_params["palette"]["default"]
-            except Exception as e:
-                print("The provided palette is invalid.")
-                raise Exception(e)
+        if "palette" in vis_params:
+            if isinstance(vis_params["palette"], tuple):
+                vis_params["palette"] = list(vis_params["palette"])
+            if isinstance(vis_params["palette"], Box):
+                try:
+                    vis_params["palette"] = vis_params["palette"]["default"]
+                except Exception as e:
+                    print("The provided palette is invalid.")
+                    raise Exception(e)
+            elif isinstance(vis_params["palette"], str):
+                vis_params["palette"] = check_cmap(vis_params["palette"])
+            elif not isinstance(vis_params["palette"], list):
+                raise ValueError(
+                    "The palette must be a list of colors or a string or a Box object."
+                )
 
         map_id_dict = ee.Image(image).getMapId(vis_params)
         url = map_id_dict["tile_fetcher"].url_format
@@ -662,7 +665,7 @@ class Map(here_map_widget.Map):
 
     def to_html(
         self,
-        outfile=None,
+        filename=None,
         title="My Map",
         width="100%",
         height="880px",
@@ -671,7 +674,7 @@ class Map(here_map_widget.Map):
         """Saves the map as an HTML file.
 
         Args:
-            outfile (str, optional): The output file path to the HTML file.
+            filename (str, optional): The output file path to the HTML file.
             title (str, optional): The title of the HTML file. Defaults to 'My Map'.
             width (str, optional): The width of the map in pixels or percentage. Defaults to '100%'.
             height (str, optional): The height of the map in pixels. Defaults to '880px'.
@@ -681,15 +684,15 @@ class Map(here_map_widget.Map):
             from ipywidgets.embed import embed_minimal_html
 
             save = True
-            if outfile is not None:
-                if not outfile.endswith(".html"):
+            if filename is not None:
+                if not filename.endswith(".html"):
                     raise ValueError("The output file extension must be html.")
-                outfile = os.path.abspath(outfile)
-                out_dir = os.path.dirname(outfile)
+                filename = os.path.abspath(filename)
+                out_dir = os.path.dirname(filename)
                 if not os.path.exists(out_dir):
                     os.makedirs(out_dir)
             else:
-                outfile = os.path.abspath(random_string() + ".html")
+                filename = os.path.abspath(random_string() + ".html")
                 save = False
 
             before_width = self.layout.width
@@ -714,17 +717,17 @@ class Map(here_map_widget.Map):
             self.layout.width = width
             self.layout.height = height
 
-            embed_minimal_html(outfile, views=[self], title=title, **kwargs)
+            embed_minimal_html(filename, views=[self], title=title, **kwargs)
 
             self.layout.width = before_width
             self.layout.height = before_height
 
             if not save:
                 out_html = ""
-                with open(outfile) as f:
+                with open(filename) as f:
                     lines = f.readlines()
                     out_html = "".join(lines)
-                os.remove(outfile)
+                os.remove(filename)
                 return out_html
 
         except Exception as e:
